# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['aeternity']

package_data = \
{'': ['*']}

install_requires = \
['Deprecated>=1.2,<2.0',
 'PyNaCl>=1.3,<2.0',
 'base58>=1.0,<2.0',
 'click>=7.0,<8.0',
 'namedtupled>=0.3.3,<0.4.0',
 'requests>=2.20,<3.0',
 'rlp>=1.1,<2.0',
 'semver>=2.8,<3.0',
 'simplejson>=3.16.0,<4.0.0',
 'validators>=0.13,<0.14',
 'websockets>=7.0,<8.0']

entry_points = \
{'console_scripts': ['aecli = aeternity.__main__:run']}

setup_kwargs = {
    'name': 'aepp-sdk',
    'version': '5.0.1',
    'description': 'Python SDK to interact with the Æternity blockchain',
    'long_description': "# aepp-sdk-python\n\n[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://commitizen.github.io/cz-cli/)\n[![Build Status](https://ci.aepps.com/buildStatus/icon?job=aepp-sdk-python/develop)](https://ci.aepps.com/job/aepp-sdk-python/job/develop/)\n[![PyPI version](https://badge.fury.io/py/aepp-sdk.svg)](https://badge.fury.io/py/aepp-sdk)\n\n## Introduction \n\n[This repo](https://github.com/aeternity/aepp-sdk-python) is for developing apps for the æternity blockchain in Python. Please see the [main dev site](https://dev.aepps.com) for instructions on accessing the testnet, and for running a local æternity node.\n\n## Installation\n\nThe SDK required Python >= 3.6. For out of the box use, it is recommended to use\n`venv` and install dependencies into it.\n\n```\npython3 -m venv venv\nsource venv/bin/activate\npip install aepp-sdk\n```\n\nWhenever you come back, don't forget to run `source venv/bin/activate`, again.\n\n\n## CLI Usage\n\nSee below for programmatic usage\n\nYou can launch the command line tool using\n\n```\n./aecli\n```\n\nAvailable commands:\n\n```\nUsage: aecli [OPTIONS] COMMAND [ARGS]...\n\n  Welcome to the aecli client.\n\n  The client is to interact with an node node.\n\nOptions:\n  --version            Show the version and exit.\n  -u, --url URL        Node node url\n  -d, --debug-url URL\n  --force              Ignore node version compatibility check\n  --wait               Wait for transactions to be included\n  --json               Print output in JSON format\n  --version            Show the version and exit.\n  --help               Show this message and exit.\n\nCommands:\n  account  Handle account operations\n  chain    Interact with the blockchain\n  config   Print the client configuration\n  inspect  Get information on transactions, blocks,...\n  name     Handle name lifecycle\n  oracle   Interact with oracles\n  tx       Handle transactions creation\n```\n\n## Environment variables\n\nUse the environment variables\n\n- `NODE_URL`\n- `NODE_URL_DEBUG`\n\n### Example usage\n\nThe following is a walkthrough to execute an offline spend transaction on the *testnet* network\n\n1. Set the environment variables\n```\nexport NODE_URL=https://sdk-testnet.aepps.com\n```\n\n❗ When not set the command line client will connect to mainnet\n\n2. Retrieve the top block\n```\n$ aecli chain top\n<top for node at https://sdk-testnet.aepps.com >\n  Beneficiary _______________________________________ ak_2iBPH7HUz3cSDVEUWiHg76MZJ6tZooVNBmmxcgVK6VV8KAE688\n  Hash ______________________________________________ kh_WTqMQQRsvmbtP5yrKPxd4p2PPKiA51AuPyCkVJk7d7HVtkhS6\n  Height ____________________________________________ 46049\n  Info ______________________________________________ cb_Xfbg4g==\n  Miner _____________________________________________ ak_24yQXT3g2jNryZbY2veHYcgQn3PspfTnkTHbXMwNYDQd9NZAs5\n  Nonce _____________________________________________ 17848795956567990671\n  Prev hash _________________________________________ kh_B5Q3F7Gxbmg2z3prkay2uYohvhv4xXUKQzKKkbTdm7Z3GuQxU\n  Prev key hash _____________________________________ kh_B5Q3F7Gxbmg2z3prkay2uYohvhv4xXUKQzKKkbTdm7Z3GuQxU\n  State hash ________________________________________ bs_bkP3QdFKCWNetDHfwL3rJG2hEgRzZRAQN6jh33SKwUd17tBjp\n  Target ____________________________________________ 538409724\n  Time ______________________________________________ 2019-03-03T23:38:49.720000+00:00\n  Version ___________________________________________ 2\n</top for node at https://sdk-testnet.aepps.com >\n```\n\n3. Create a new account\n\n```\naecli account create Bob.json\nEnter the account password []:\n<account>\n  Address ___________________________________________ ak_BobY97QUVR4iDLg4k3RKmy6shZYx9FR75nLaN33GsVmSnhWxn\n  Path ______________________________________________ /.../Bob.json\n</account>\n\n```\n\n❗ Make sure that you use a long and difficult-to-guess password for an account that you plan to use on mainnet\n\n4. Go to [testnet.faucet.aepps.com](https://testnet.faucet.aepps.com) and top up your account\n\n![](docs/assets/images/faucet.png)\n\n5. Inspect the transaction reported by the faucet app\n```\naecli inspect th_2CV4a7xxDYj5ysaDjXNoCSLxnkowGM5bbyAvtdoPvHZwTSYykX\n<transaction>\n  Block hash ________________________________________ mh_2vjFffExUZPVGo3q6CHRSzxVUhzLcUnQQUWpijFtSvKfoHwQWe\n  Block height ______________________________________ 12472\n  Hash ______________________________________________ th_2CV4a7xxDYj5ysaDjXNoCSLxnkowGM5bbyAvtdoPvHZwTSYykX\n  <signatures 1>\n    Signature #1 ____________________________________ sg_WtPeyKWN4zmcnZZXpAxCT8EvjF3qSjiUidc9cdxQooxe1JCLADTVbKDFm9S5bNwv3yq57PQKTG4XuUP4eTzD5jymPHpNu\n  </signatures>\n  <tx>\n    Amount __________________________________________ 5AE\n    Fee _____________________________________________ 0.00001686AE\n    Nonce ___________________________________________ 146\n    Payload _________________________________________ Faucet Tx\n    Recipient id ____________________________________ ak_2ioQbdSViNKjknaLUWphdRjpbTNVpMHpXf9X5ZkoVrhrCZGuyW\n    Sender id _______________________________________ ak_2iBPH7HUz3cSDVEUWiHg76MZJ6tZooVNBmmxcgVK6VV8KAE688\n    Ttl _____________________________________________ 12522\n    Type ____________________________________________ SpendTx\n    Version _________________________________________ 1\n  </tx>\n</transaction>\n```\n\n6. Create another account\n\n```\naecli account create Alice.json\nEnter the account password []:\n<account>\n  Address ___________________________________________ ak_9j8akv2PE2Mnt5khFeDvS9BGc3TBBrJkfcgaJHgBXcLLagX8M\n  Path ______________________________________________ /.../Alice.json\n</account>\n```\n\n\n7. Transfer some tokens to an account to the other\n\n```\naecli account spend Bob.json ak_9j8akv2PE2Mnt5khFeDvS9BGc3TBBrJkfcgaJHgBXcLLagX8M 1000000000000000000\nEnter the account password []:\n<spend transaction>\n  <data>\n    Tag _____________________________________________ 12\n    Vsn _____________________________________________ 1\n    Sender id _______________________________________ ak_BobY97QUVR4iDLg4k3RKmy6shZYx9FR75nLaN33GsVmSnhWxn\n    Recipient id ____________________________________ ak_9j8akv2PE2Mnt5khFeDvS9BGc3TBBrJkfcgaJHgBXcLLagX8M\n    Amount __________________________________________ 1AE\n    Fee _____________________________________________ 0.00001686AE\n    Ttl _____________________________________________ 0\n    Nonce ___________________________________________ 4\n    Payload _________________________________________\n  </data>\n  Metadata\n  Tx ________________________________________________ tx_+KMLAfhCuEAKN05UwTV0fSgO5woziVNnAMBcDrh46XlNFTZTJQlI05fz/8pVSyrb1guCLcw8n7++O887k/JEu6/XHcCSHOMMuFv4WQwBoQEYh8aMDs7saMDBvys+lbKds3Omnzm4crYNbs9xGolBm6EBE9B4l/BeyxMO//3ANxwyT+ZHL52j9nAZosRe/YFuK4eIDeC2s6dkAACGD1WGT5gAAASAN24JGA==\n  Hash ______________________________________________ th_2gAL72dtnaeDcZoZA9MbfSL1JrWzNErMJuikmTRvBY8zhkGh91\n  Signature _________________________________________ sg_2LX9hnJRiYGSspzpS34QeN3PLT9bGSkFRbad9LXvLj5QUFoV5eHRf9SueDgLiiquCGbeFEBPBe7xMJidf8NMSuF16dngr\n  Network id ________________________________________ ae_uat\n</spend transaction>\n```\n\n8. Verify the balance of the new account\n```\naecli inspect ak_9j8akv2PE2Mnt5khFeDvS9BGc3TBBrJkfcgaJHgBXcLLagX8M\n<account>\n  Balance ___________________________________________ 1AE\n  Id ________________________________________________ ak_9j8akv2PE2Mnt5khFeDvS9BGc3TBBrJkfcgaJHgBXcLLagX8M\n  Nonce _____________________________________________ 0\n</account>\n```\n\n\n\n## Advanced usage\n\nFor advanced usage check the [documentation](docs).\n\n\n## Reference:\n\n[AENS API Spec](https://github.com/aeternity/protocol/blob/master/node/api/naming_system_api_usage.md)\n\n[AENS Protocol](https://github.com/aeternity/protocol/blob/master/AENS.md)\n",
    'author': 'Andrea Giacobino',
    'author_email': 'no.andrea@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/aeternity/aepp-sdk-python',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
